tic_wir: Return wash in rate from time-intensity data
Description
This function returns the wash in rate from time-intensity curve data. Raw data
is smoothed using a loess smoother. Wash in rate is calculated as the maximum upward
slope of the loess curve before peak intensity is reached. It is recommended that
plotresult is set to TRUE in the first instance to visually confirm the analysis.
Usage
tic_wir(data, timevar, intensityvar, loess.span = 0.1, plotresult = FALSE, ...)
Value
The wash in rate. Depending on the plotresult argument can also
return a plot of the smoothed curve with the calculated slope shown.
Arguments
- data
A dataframe with time and intensity values as columns.
- timevar
A character string (in quotes) with the dataframe column name for the time variable.
- intensityvar
A character string (in quotes) with dataframe column name for the intensity variable.
- loess.span
A number between 0 and 1, with larger values resulting in a smoother curve.
- plotresult
TRUE or FALSE to determine whether a plot of the results is generated.
- ...
Additional arguments to be passed into the loess() function.
Examples
Run this code
# Example usage: Please see package vignettes on CRAN
Run the code above in your browser using DataLab